@@ -257,21 +257,21 @@ def append_acl_cli(root_sp):
     p = sp.add_parser('list', help='list ACLs')
     p.add_argument('-a',
                    '--acl-svc',
-                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE}',
+                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE})',
                    default=DEFAULT_ACL_SERVICE).completer = ComplSvc('aaa')
 
     p = sp.add_parser('edit', help='edit ACL')
     p.add_argument('i', metavar='ACL')
     p.add_argument('-a',
                    '--acl-svc',
-                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE}',
+                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE})',
                    default=DEFAULT_ACL_SERVICE).completer = ComplSvc('aaa')
 
     p = sp.add_parser('export', help='export ACLs(s) to a deployment file')
     p.add_argument('i', metavar='MASK')
     p.add_argument('-a',
                    '--acl-svc',
-                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE}',
+                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE})',
                    default=DEFAULT_ACL_SERVICE).completer = ComplSvc('aaa')
     p.add_argument('-o', '--output', metavar='FILE',
                    help='output file').completer = ComplYamlFile()
@@ -279,7 +279,7 @@ def append_acl_cli(root_sp):
     p = sp.add_parser('deploy', help='deploy ACL(s) from a deployment file')
     p.add_argument('-a',
                    '--acl-svc',
-                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE}',
+                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE})',
                    default=DEFAULT_ACL_SERVICE).completer = ComplSvc('aaa')
     p.add_argument('-f', '--file', metavar='FILE',
                    help='deployment file').completer = ComplYamlFile()
@@ -288,7 +288,7 @@ def append_acl_cli(root_sp):
                       help='undeploy ACL(s) using a deployment file')
     p.add_argument('-a',
                    '--acl-svc',
-                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE}',
+                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE})',
                    default=DEFAULT_ACL_SERVICE).completer = ComplSvc('aaa')
     p.add_argument('-f', '--file', metavar='FILE',
                    help='deployment file').completer = ComplYamlFile()
@@ -297,14 +297,14 @@ def append_acl_cli(root_sp):
     p.add_argument('i', metavar='ACL', help='ACL id')
     p.add_argument('-a',
                    '--acl-svc',
-                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE}',
+                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE})',
                    default=DEFAULT_ACL_SERVICE).completer = ComplSvc('aaa')
 
     p = sp.add_parser('destroy', help='destroy ACL')
     p.add_argument('i', metavar='ACL')
     p.add_argument('-a',
                    '--acl-svc',
-                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE}',
+                   help=f'ACL service (default: {DEFAULT_ACL_SERVICE})',
                    default=DEFAULT_ACL_SERVICE).completer = ComplSvc('aaa')
 
 
@@ -315,7 +315,7 @@ def append_key_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
 
     p = sp.add_parser('get', help='get API key data (including the key field)')
@@ -323,7 +323,7 @@ def append_key_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
 
     p = sp.add_parser('edit', help='edit API key')
@@ -331,7 +331,7 @@ def append_key_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
 
     p = sp.add_parser('export', help='export API keys(s) to a deployment file')
@@ -339,7 +339,7 @@ def append_key_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
     p.add_argument('-o', '--output', metavar='FILE',
                    help='output file').completer = ComplYamlFile()
@@ -348,7 +348,7 @@ def append_key_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
     p.add_argument('-f', '--file', metavar='FILE',
                    help='deployment file').completer = ComplYamlFile()
@@ -358,7 +358,7 @@ def append_key_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
     p.add_argument('-f', '--file', metavar='FILE',
                    help='deployment file').completer = ComplYamlFile()
@@ -368,7 +368,7 @@ def append_key_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
 
     p = sp.add_parser('destroy', help='destroy API key')
@@ -376,7 +376,7 @@ def append_key_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
 
     p = sp.add_parser('regenerate', help='re-generate API key')
@@ -384,7 +384,7 @@ def append_key_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
 
 
@@ -395,7 +395,7 @@ def append_user_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
 
     p = sp.add_parser('get', help='get user data')
@@ -403,7 +403,7 @@ def append_user_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
 
     p = sp.add_parser('edit', help='edit user')
@@ -411,7 +411,7 @@ def append_user_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
 
     p = sp.add_parser('export', help='export users(s) to a deployment file')
@@ -419,7 +419,7 @@ def append_user_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
     p.add_argument('-o', '--output', metavar='FILE',
                    help='output file').completer = ComplYamlFile()
@@ -428,7 +428,7 @@ def append_user_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
     p.add_argument('-f', '--file', metavar='FILE',
                    help='deployment file').completer = ComplYamlFile()
@@ -438,7 +438,7 @@ def append_user_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
     p.add_argument('-f', '--file', metavar='FILE',
                    help='deployment file').completer = ComplYamlFile()
@@ -448,7 +448,7 @@ def append_user_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
 
     p = sp.add_parser('destroy', help='destroy user')
@@ -456,7 +456,7 @@ def append_user_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
 
     p = sp.add_parser('password', help='change user\'s password')
@@ -464,7 +464,7 @@ def append_user_cli(root_sp):
     p.add_argument(
         '-a',
         '--auth-svc',
-        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE}',
+        help=f'Authentication service (default: {DEFAULT_AUTH_SERVICE})',
         default=DEFAULT_AUTH_SERVICE).completer = ComplSvc('aaa')
 
 
