@@ -4,7 +4,7 @@ import time
 from functools import partial
 
 import elbus
-import msgpack
+from evaics.sdk import pack
 from neotermcolor import colored
 from rapidtables import format_table, FORMAT_GENERATOR, FORMAT_GENERATOR_COLS
 
@@ -89,8 +89,11 @@ class CLI:
         eva_control_c('status')
 
     def cloud_deploy(self, file, config_var, config, test):
-        args = (f'cloud deploy --timeout {current_command.timeout}'
-                f' --connection-path "{common.elbus_path}" "{file}"')
+        args = ''
+        if current_command.debug:
+            args += ' --verbose '
+        args += (f'cloud deploy --timeout {current_command.timeout}'
+                 f' --connection-path "{common.elbus_path}" "{file}"')
         if config_var:
             for c in config_var:
                 args += f' --config-var "{c}"'
@@ -101,8 +104,11 @@ class CLI:
         exec_cmd('eva-cloud-manager', args)
 
     def cloud_undeploy(self, file, config_var, config, test):
-        args = (f'cloud undeploy --timeout {current_command.timeout}'
-                f' --connection-path "{common.elbus_path}" "{file}"')
+        args = ''
+        if current_command.debug:
+            args += ' --verbose '
+        args += (f'cloud undeploy --timeout {current_command.timeout}'
+                 f' --connection-path "{common.elbus_path}" "{file}"')
         if config_var:
             for c in config_var:
                 args += f' --config-var "{c}"'
@@ -115,10 +121,13 @@ class CLI:
     def cloud_update(self, nodes, check_timeout, all, info_only, yes):
         if not nodes and not all:
             raise RuntimeError('specify either nodes to update or --all')
-        args = (f'cloud update --timeout {current_command.timeout}'
-                f' --connection-path "{common.elbus_path}"'
-                f' --check-timeout "{check_timeout}"')
-        args += ' ' + ' '.join(nodes)
+        args = ''
+        if current_command.debug:
+            args += ' --verbose '
+        args += (f'cloud update --timeout {current_command.timeout}'
+                 f' --connection-path "{common.elbus_path}"'
+                 f' --check-timeout "{check_timeout}"')
+        args += ' ' + ' '.join([f'"{n}"' for n in nodes])
         if all:
             args += ' --all'
         if info_only:
@@ -128,7 +137,10 @@ class CLI:
         exec_cmd('eva-cloud-manager', args)
 
     def update(self, download_timeout, repository_url, yes, info_only, test):
-        args = f'node update --timeout {current_command.timeout}'
+        args = ''
+        if current_command.debug:
+            args += ' --verbose '
+        args += f'node update --timeout {current_command.timeout}'
         if repository_url:
             args = + f' --repository-url "{repository_url}"'
         if download_timeout:
@@ -245,7 +257,6 @@ class CLI:
         edit_config(config, f'acl|{i}|config', deploy_fn=partial(deploy, i=i))
 
     def acl_export(self, i, acl_svc, output=None):
-        import yaml
         c = 0
         configs = []
         for acl in call_rpc('acl.list', target=acl_svc):
@@ -256,13 +267,18 @@ class CLI:
                 i == name:
                 c += 1
                 configs.append(acl)
-        dump = yaml.dump(dict(acls=configs), default_flow_style=False)
-        if output is None:
-            print(dump)
+        result = dict(acls=configs)
+        if current_command.json:
+            print_result(result)
         else:
-            write_file(output, dump)
-            print(f'{c} ACL(s) exported')
-            print()
+            import yaml
+            dump = yaml.dump(result, default_flow_style=False)
+            if output is None:
+                print(dump)
+            else:
+                write_file(output, dump)
+                print(f'{c} ACL(s) exported')
+                print()
 
     def acl_deploy(self, acl_svc, file=None):
         import yaml
@@ -304,7 +320,6 @@ class CLI:
         edit_config(config, f'key|{i}|config', deploy_fn=partial(deploy, i=i))
 
     def key_export(self, i, auth_svc, output=None):
-        import yaml
         c = 0
         configs = []
         for key in call_rpc('key.list', target=auth_svc):
@@ -315,13 +330,18 @@ class CLI:
                 i == name:
                 c += 1
                 configs.append(key)
-        dump = yaml.dump(dict(keys=configs), default_flow_style=False)
-        if output is None:
-            print(dump)
+        result = dict(keys=configs)
+        if current_command.json:
+            print_result(result)
         else:
-            write_file(output, dump)
-            print(f'{c} API key(s) exported')
-            print()
+            import yaml
+            dump = yaml.dump(result, default_flow_style=False)
+            if output is None:
+                print(dump)
+            else:
+                write_file(output, dump)
+                print(f'{c} API key(s) exported')
+                print()
 
     def key_deploy(self, auth_svc, file=None):
         import yaml
@@ -378,7 +398,6 @@ class CLI:
         edit_config(config, f'user|{i}|config', deploy_fn=partial(deploy, i=i))
 
     def user_export(self, i, auth_svc, output=None):
-        import yaml
         c = 0
         configs = []
         for user in call_rpc('user.list', target=auth_svc):
@@ -389,13 +408,18 @@ class CLI:
                 i == name:
                 c += 1
                 configs.append(user)
-        dump = yaml.dump(dict(users=configs), default_flow_style=False)
-        if output is None:
-            print(dump)
+        result = dict(users=configs)
+        if current_command.json:
+            print_result(result)
         else:
-            write_file(output, dump)
-            print(f'{c} user(s) exported')
-            print()
+            import yaml
+            dump = yaml.dump(result, default_flow_style=False)
+            if output is None:
+                print(dump)
+            else:
+                write_file(output, dump)
+                print(f'{c} user(s) exported')
+                print()
 
     def user_deploy(self, auth_svc, file=None):
         import yaml
@@ -446,7 +470,6 @@ class CLI:
         print_result(data, cols=['id', 'status', 'pid', 'launcher'])
 
     def svc_export(self, i, output=None):
-        import yaml
         c = 0
         configs = []
         for svc in call_rpc('svc.list'):
@@ -459,13 +482,18 @@ class CLI:
                 configs.append(
                     dict(id=name,
                          params=call_rpc('svc.get_params', dict(i=name))))
-        dump = yaml.dump(dict(svcs=configs), default_flow_style=False)
-        if output is None:
-            print(dump)
+        result = dict(svcs=configs)
+        if current_command.json:
+            print_result(result)
         else:
-            write_file(output, dump)
-            print(f'{c} service(s) exported')
-            print()
+            import yaml
+            dump = yaml.dump(dict(svcs=configs), default_flow_style=False)
+            if output is None:
+                print(dump)
+            else:
+                write_file(output, dump)
+                print(f'{c} service(s) exported')
+                print()
 
     def svc_deploy(self, file=None):
         import yaml
@@ -752,16 +780,19 @@ class CLI:
                     deploy_fn=partial(deploy_edited_node, i=i))
 
     def node_export(self, i, repl_svc, output=None):
-        import yaml
         configs = call_rpc('node.export', dict(i=i), target=repl_svc)
         c = len(configs['nodes'])
-        dump = yaml.dump(configs, default_flow_style=False)
-        if output is None:
-            print(dump)
+        if current_command.json:
+            print_result(configs)
         else:
-            write_file(output, dump)
-            print(f'{c} node(s) exported')
-            print()
+            import yaml
+            dump = yaml.dump(configs, default_flow_style=False)
+            if output is None:
+                print(dump)
+            else:
+                write_file(output, dump)
+                print(f'{c} node(s) exported')
+                print()
 
     def node_test(self, i, repl_svc):
         call_rpc('node.test', dict(i=i), target=repl_svc)
@@ -813,19 +844,23 @@ class CLI:
         ok()
 
     def item_export(self, i, output=None):
-        import yaml
         c = 0
         configs = []
         for item in call_rpc('item.list', dict(i=i, node='.local')):
             c += 1
             configs.append(call_rpc('item.get_config', dict(i=item['oid'])))
-        dump = yaml.dump(dict(items=configs), default_flow_style=False)
-        if output is None:
-            print(dump)
+        result = dict(items=configs)
+        if current_command.json:
+            print_result(result)
         else:
-            write_file(output, dump)
-            print(f'{c} item(s) exported')
-            print()
+            import yaml
+            dump = yaml.dump(result, default_flow_style=False)
+            if output is None:
+                print(dump)
+            else:
+                write_file(output, dump)
+                print(f'{c} item(s) exported')
+                print()
 
     def item_set(self, i, status, value):
         payload = dict(status=status, force=True)
@@ -834,8 +869,7 @@ class CLI:
             payload['value'] = val
         common.bus.send(
             'RAW/' + i.replace(':', '/', 1),
-            elbus.client.Frame(msgpack.dumps(payload),
-                               tp=elbus.client.OP_PUBLISH,
+            elbus.client.Frame(pack(payload), tp=elbus.client.OP_PUBLISH,
                                qos=1)).wait_completed()
         time.sleep(0.1)
         state = call_rpc('item.state', dict(i=i))[0]
@@ -1158,12 +1192,18 @@ class CLI:
         print_result(d, need_header=False, name_value=False)
 
     def mirror_set(self, mirror_url):
-        args = f'node mirror-set "{mirror_url}"'
+        args = ''
+        if current_command.debug:
+            args += ' --verbose '
+        args += f'node mirror-set "{mirror_url}"'
         exec_cmd('eva-cloud-manager', args)
         self.venv_mirror_set(mirror_url=mirror_url)
 
     def mirror_update(self, dest, current_arch_only, force, repository_url):
-        args = f'node mirror-update --timeout {current_command.timeout}'
+        args = ''
+        if current_command.debug:
+            args += ' --verbose '
+        args += f'node mirror-update --timeout {current_command.timeout}'
         if dest:
             args += f' --dest "{dest}"'
         if repository_url:
