@@ -1,8 +1,10 @@
 import logging
+
 from .sharedobj import common, current_command
 from .tools import debug
+
 import elbus
-import msgpack
+from evaics.sdk import pack, unpack
 
 logger = logging.getLogger('elbus.client')
 logger.setLevel(logging.CRITICAL)
@@ -26,11 +28,11 @@ def call_rpc(method, params=None, target='eva.core'):
         debug(f'params: {params}')
     result = common.rpc.call(
         target,
-        elbus.rpc.Request(method,
-                          params=b'' if params is None else
-                          msgpack.dumps(params))).wait_completed(
-                              timeout=current_command.timeout)
+        elbus.rpc.Request(
+            method,
+            params=b'' if params is None else pack(params))).wait_completed(
+                timeout=current_command.timeout)
     if result.is_empty():
         return None
     else:
-        return msgpack.loads(result.get_payload(), raw=False)
+        return unpack(result.get_payload())
